@@ -1,5 +1,6 @@
 """Config parser for Buildout Versions Checker"""
 import re
+from operator import itemgetter
 try:
     from ConfigParser import RawConfigParser
 except ImportError:  # Python 3
@@ -15,13 +16,27 @@ class VersionsConfigParser(RawConfigParser):
     """
     optionxform = str
 
-    def write_section(self, fd, section, indentation):
+    def alpha_sorter(self, items):
+        return sorted(items, key=itemgetter(0))
+
+    def length_sorter(self, items):
+        return sorted(self.alpha_sorter(items),
+                      key=lambda x: len(x[0]))
+
+    def write_section(self, fd, section, indentation, sorting):
         """
         Write a section of an .ini-format
         and all the keys within.
         """
         string_section = '[%s]\n' % section
-        for key, value in self._sections[section].items():
+
+        items = self._sections[section].items()
+        try:
+            items = getattr(self, '%s_sorter' % sorting)(items)
+        except (TypeError, AttributeError):
+            pass
+
+        for key, value in items:
             if key == '__name__':
                 continue
             if value is None:
@@ -44,7 +59,7 @@ class VersionsConfigParser(RawConfigParser):
 
         fd.write(string_section.encode('utf-8'))
 
-    def write(self, source, indentation=32):
+    def write(self, source, indentation=32, sorting=None):
         """
         Write an .ini-format representation of the
         configuration state with a readable indentation.
@@ -52,6 +67,6 @@ class VersionsConfigParser(RawConfigParser):
         with open(source, 'wb') as fd:
             sections = list(self._sections.keys())
             for section in sections[:-1]:
-                self.write_section(fd, section, indentation)
+                self.write_section(fd, section, indentation, sorting)
                 fd.write('\n'.encode('utf-8'))
-            self.write_section(fd, sections[-1], indentation)
+            self.write_section(fd, sections[-1], indentation, sorting)
